CanvasPie class

A list of CanvasPieSlices to be painted by ChartCanvas.

Constructors

CanvasPie(List<CanvasPieSlice> slices, Point<num> center, double radius, double innerRadius, {Color? stroke, double strokeWidthPx = 0.0})

Properties

center ↔ Point<num>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
innerRadius ↔ double
getter/setter pair
radius ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slices → List<CanvasPieSlice>
final
stroke → Color?
Color of separator lines between arcs.
final
strokeWidthPx ↔ double
Stroke width of separator lines between arcs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited