DatumDetails<D> class

Represents processed rendering details for a data point from a series.

Constructors

DatumDetails({dynamic datum, int? index, D? domain, DomainFormatter<D>? domainFormatter, D? domainLowerBound, D? domainUpperBound, num? measure, MeasureFormatter? measureFormatter, num? measureLowerBound, num? measureUpperBound, num? measureOffset, num? rawMeasure, num? rawMeasureLowerBound, num? rawMeasureUpperBound, ImmutableSeries<D>? series, Color? color, Color? fillColor, FillPatternType? fillPattern, Color? areaColor, List<int>? dashPattern, NullablePoint? chartPosition, NullablePoint? chartPositionLower, NullablePoint? chartPositionUpper, Rectangle<int>? bounds, double? domainDistance, double? measureDistance, double? relativeDistance, double? radiusPx, SymbolRenderer? symbolRenderer, double? strokeWidthPx})
DatumDetails.from(DatumDetails<D> other, {D? datum, int? index, D? domain, D? domainLowerBound, D? domainUpperBound, num? measure, MeasureFormatter? measureFormatter, num? measureLowerBound, num? measureUpperBound, num? measureOffset, num? rawMeasure, num? rawMeasureLowerBound, num? rawMeasureUpperBound, ImmutableSeries<D>? series, Color? color, Color? fillColor, FillPatternType? fillPattern, Color? areaColor, List<int>? dashPattern, NullablePoint? chartPosition, NullablePoint? chartPositionLower, NullablePoint? chartPositionUpper, Rectangle<int>? bounds, DomainFormatter<D>? domainFormatter, double? domainDistance, double? measureDistance, double? radiusPx, SymbolRenderer? symbolRenderer, double? strokeWidthPx})
factory

Properties

areaColor → Color?
Optional area color of this datum.
final
bounds → Rectangle<int>?
The bounding box for the chart space occupied by this datum.
final
chartPosition → NullablePoint?
The chart position of the (domain, measure) for the datum from a renderer.
final
chartPositionLower → NullablePoint?
The chart position of the (domainLowerBound, measureLowerBound) for the datum from a renderer.
final
chartPositionUpper → NullablePoint?
The chart position of the (domainUpperBound, measureUpperBound) for the datum from a renderer.
final
color → Color?
The color of this datum.
final
dashPattern → List<int>?
Optional dash pattern of this datum.
final
datum → dynamic
final
domain → D?
Domain value of datum.
final
domainDistance → double?
Distance of domain from a given (x, y) coordinate.
final
domainFormatter ↔ DomainFormatter<D>?
Optional formatter for domain.
getter/setter pair
domainLowerBound → D?
Domain lower bound value of datum. This may represent an error bound, or a previous domain value.
final
domainUpperBound → D?
Domain upper bound value of datum. This may represent an error bound, or a target domain value.
final
fillColor → Color?
Optional fill color of this datum.
final
fillPattern → FillPatternType?
Optional fill pattern of this datum.
final
formattedDomain → String
no setter
formattedMeasure → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int?
The index of the datum in the series.
final
measure → num?
Measure value of datum.
final
measureDistance → double?
Distance of measure from a given (x, y) coordinate.
final
measureFormatter ↔ MeasureFormatter?
Optional formatter for measure.
getter/setter pair
measureLowerBound → num?
Measure lower bound value of datum. This may represent an error bound, or a previous value.
final
measureOffset → num?
Measure offset value of datum.
final
measureUpperBound → num?
Measure upper bound value of datum. This may represent an error bound, or a target measure value.
final
radiusPx → double?
The radius of this datum.
final
rawMeasure → num?
Original measure value of datum. This may differ from measure if a behavior attached to a chart automatically adjusts measure values.
final
rawMeasureLowerBound → num?
Original measure lower bound value of datum. This may differ from measureLowerBound if a behavior attached to a chart automatically adjusts measure values.
final
rawMeasureUpperBound → num?
Original measure upper bound value of datum. This may differ from measureUpperBound if a behavior attached to a chart automatically adjusts measure values.
final
relativeDistance → double?
Relative Cartesian distance of (domain, measure) from a given (x, y) coordinate.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series → ImmutableSeries<D>?
The series the datum is from.
final
strokeWidthPx → double?
The stroke width of this datum.
final
symbolRenderer → SymbolRenderer?
Renderer used to draw the shape of this datum.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited