LegendCategory<D> class

When the legend groups by category it will create additional legend entries that track styling and grouping on a per category basis.

Inheritance

Constructors

LegendCategory(String label, List<LegendEntry<D>>? entries, {TextStyleSpec? textStyle, int? rowNumber, int? columnNumber, int? rowCount, int? columnCount, bool? inFirstRow, bool? inFirstColumn, bool? inLastRow, bool? inLastColumn})

Properties

columnCount ↔ int?
Total number of columns in the legend.
getter/setter pairinherited
columnNumber ↔ int?
Zero based index for the column where this legend appears in the legend.
getter/setter pairinherited
entries → List<LegendEntry<D>>?
The list of entries that should be displayed within this category.
final
hashCode → int
The hash code for this object.
no setterinherited
inFirstColumn ↔ bool?
Indicates whether this is in the first column of a tabular layout.
getter/setter pairinherited
inFirstRow ↔ bool?
Indicates whether this is in the first row of a tabular layout.
getter/setter pairinherited
inLastColumn ↔ bool?
Indicates whether this is in the last column of a tabular layout.
getter/setter pairinherited
inLastRow ↔ bool?
Indicates whether this is in the last row of a tabular layout.
getter/setter pairinherited
label → String
finalinherited
rowCount ↔ int?
Total number of rows in the legend.
getter/setter pairinherited
rowNumber ↔ int?
Zero based index for the row where this legend appears in the legend.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyleSpec?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited